@@ -606,7 +606,7 @@ class Window(gtk.Window):
         self.g_new_dependency.connect('clicked', self.on_add_dep)
         self.g_new_dependency.set_sensitive(False)
         vbox.pack_start(self.g_new_dependency, False)
-        self.g_delete_dependency = gtk.Button(_("Delete depencency"))
+        self.g_delete_dependency = gtk.Button(_("Delete dependency"))
         self.g_delete_dependency.connect('clicked', self.on_delete_dep)
         self.g_delete_dependency.set_sensitive(False)
         vbox.pack_start(self.g_delete_dependency, False)
@@ -753,7 +753,7 @@ class Window(gtk.Window):
         try:
             self.m_tree.save(filename)
         except IOError, e:
-            gu.dialog_ok(_("An error occured while saving the file:\n%s") % e,
+            gu.dialog_ok(_("An error occurred while saving the file:\n%s") % e,
                     self)
             return False
         return True
