@@ -143,7 +143,7 @@ class Gui(abstract.LessonbasedGui):
                 self.g_music_displayer.display(self.m_t.get_music_string(),
                     self.get_int('config/feta_font_size=20'))
             else:
-                self.g_win.display_error_message(_("Could not satisfy the contraints in the lesson header. The lesson file need to be adjusted."))
+                self.g_win.display_error_message(_("Could not satisfy the constraints in the lesson header. The lesson file need to be adjusted."))
         except lessonfile.LessonfileException, e:
             self.g_win.display_exception_message(e, __file__)
     def on_interval_quality_clicked(self, button, n):
