@@ -190,6 +190,13 @@ def check_file(filename):
             print "%s != %s" % (a, b)
             print "Entry status:", entry.get_status()
             print
+        # Check for notename| strings
+        if entry.get_msgid().startswith("notename|"):
+            if "|" in entry.get_msgstr():
+                file_ok = False
+                print "%s:" % filename
+                print "'|' in translated notename entry:"
+                print 'msgid: "%s"' % entry.get_msgid()
     return file_ok
 
 
